pub struct DualPcm<'a, T> {
pub left: &'a [T],
pub right: &'a [T],
}Expand description
PCM data represented by two channels.
Number of samples must be equal between left and right channels.
If you want to feed encoder single PCM data, then use MonoPcm In case length of channels is not equal, it will always feed encoder minimum of both length. In debug mode it will panic in this case also to warn you of error.
Fields
left: &'a [T]left channel PCM data
right: &'a [T]right channel PCM data